"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  CurrencyResult: () => CurrencyResult,
  DictionaryResult: () => DictionaryResult,
  OrganicResult: () => OrganicResult,
  ResultTypes: () => ResultTypes,
  TimeResult: () => TimeResult,
  TranslateResult: () => TranslateResult,
  search: () => search,
  searchWithPages: () => searchWithPages
});
module.exports = __toCommonJS(src_exports);

// src/search.ts
var import_axios = __toESM(require("axios"));
var import_cheerio = require("cheerio");

// src/results.ts
var import_google_sr_selectors = require("google-sr-selectors");

// src/constants.ts
var ResultTypes = {
  OrganicResult: "ORGANIC",
  TranslateResult: "TRANSLATE",
  DictionaryResult: "DICTIONARY",
  TimeResult: "TIME",
  CurrencyResult: "CURRENCY"
};

// src/utils.ts
var baseHeaders = {
  Accept: "text/html",
  "Accept-Encoding": "gzip, deflate",
  "Accept-Language": "en-US,en",
  Referer: "https://www.google.com/",
  "upgrade-insecure-requests": 1,
  // the tested user agent is for Chrome 103 on Windows 10
  "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/103.0.0.0 Safari/537.36"
};
function extractUrlFromGoogleLink(googleLink) {
  const match = googleLink.match(/\/url\?q=([^&]+)/);
  if (match) {
    const decodedUrl = decodeURIComponent(match[1]);
    return decodedUrl;
  }
  return null;
}
__name(extractUrlFromGoogleLink, "extractUrlFromGoogleLink");
function prepareRequestConfig(opts) {
  const requestConfig = opts.requestConfig ?? {};
  if (typeof opts.query !== "string")
    throw new TypeError(
      `Search query must be a string, received ${typeof opts.query} instead.`
    );
  if (typeof requestConfig !== "object")
    throw new TypeError(
      `Request config must be an object if specified, received ${typeof requestConfig}.`
    );
  requestConfig.headers = requestConfig.headers ? Object.assign({}, baseHeaders, requestConfig.headers) : baseHeaders;
  requestConfig.url = requestConfig.url ?? "https://www.google.com/search";
  if (!(requestConfig.params instanceof URLSearchParams)) {
    requestConfig.params = new URLSearchParams(requestConfig.params);
  }
  requestConfig.params.set("q", opts.query);
  requestConfig.params.set("gbv", "1");
  requestConfig.responseType = "text";
  return requestConfig;
}
__name(prepareRequestConfig, "prepareRequestConfig");
function throwNoCheerioError(resultParserName) {
  throw new TypeError(
    `CheerioAPI instance is missing, if using as a selector make sure to pass the raw function and not the result of calling it. (ex: [${resultParserName}] instead of [${resultParserName}()])`
  );
}
__name(throwNoCheerioError, "throwNoCheerioError");
function isEmpty(strictSelector, ...values) {
  if (strictSelector)
    return values.some(
      (value) => value === "" || value === void 0 || value === null
    );
  return values.every(
    (value) => value === "" || value === void 0 || value === null
  );
}
__name(isEmpty, "isEmpty");

// src/results.ts
var OrganicResult = /* @__PURE__ */ __name(($, strictSelector) => {
  if (!$)
    throwNoCheerioError("OrganicResult");
  const parsedResults = [];
  const organicSearchBlocks = $(import_google_sr_selectors.OrganicSearchSelector.block).toArray();
  for (const element of organicSearchBlocks) {
    let link = $(element).find(import_google_sr_selectors.OrganicSearchSelector.link).attr("href");
    const description = $(element).find(import_google_sr_selectors.OrganicSearchSelector.description).text();
    const title = $(element).find(import_google_sr_selectors.OrganicSearchSelector.title).text();
    if (typeof link === "string")
      link = extractUrlFromGoogleLink(link);
    if (isEmpty(strictSelector, link, description, title))
      continue;
    parsedResults.push({
      type: ResultTypes.OrganicResult,
      link,
      description,
      title
    });
  }
  return parsedResults;
}, "OrganicResult");
var TranslateResult = /* @__PURE__ */ __name(($, strictSelector) => {
  if (!$)
    throwNoCheerioError("TranslateResult");
  const sourceLanguage = $(import_google_sr_selectors.TranslateSearchSelector.sourceLanguage).text().trim();
  const sourceText = $(import_google_sr_selectors.TranslateSearchSelector.sourceText).val();
  const translationText = $(import_google_sr_selectors.TranslateSearchSelector.translationText).text().trim();
  const translationLanguage = $(import_google_sr_selectors.TranslateSearchSelector.targetLanguage).text().trim();
  const translationPronunciation = $(import_google_sr_selectors.TranslateSearchSelector.pronunciation).text().trim();
  if (isEmpty(
    strictSelector,
    sourceLanguage,
    translationLanguage,
    sourceText,
    translationText,
    translationPronunciation
  ))
    return null;
  return {
    type: ResultTypes.TranslateResult,
    sourceLanguage,
    sourceText,
    translationLanguage,
    translationText,
    translationPronunciation
  };
}, "TranslateResult");
var DictionaryResult = /* @__PURE__ */ __name(($, strictSelector) => {
  if (!$)
    throwNoCheerioError("DictionaryResult");
  const audio = $(import_google_sr_selectors.DictionarySearchSelector.audio).attr("src") || "";
  const phonetic = $(import_google_sr_selectors.DictionarySearchSelector.phonetic).first().text().trim();
  const word = $(import_google_sr_selectors.DictionarySearchSelector.word).text().trim();
  const definitions = [];
  const definitionElements = $(import_google_sr_selectors.DictionarySearchSelector.definitionPartOfSpeech);
  for (let i = 0; i < definitionElements.length; i++) {
    const partOfSpeech = $(definitionElements[i]).text().trim();
    if (partOfSpeech) {
      const definition = $(import_google_sr_selectors.DictionarySearchSelector.definition).eq(i).text().trim();
      const example = $(import_google_sr_selectors.DictionarySearchSelector.definitionExample).eq(i).text().trim();
      const synonyms = $(import_google_sr_selectors.DictionarySearchSelector.definitionSynonyms).eq(i).text().replace("synonyms: ", "").split(",").map((synonym) => synonym.trim());
      definitions.push({
        partOfSpeech,
        definition,
        example,
        synonyms
      });
    }
  }
  if (isEmpty(strictSelector, audio, phonetic, word))
    return null;
  return {
    type: ResultTypes.DictionaryResult,
    audio,
    phonetic,
    word,
    definitions
  };
}, "DictionaryResult");
var TimeResult = /* @__PURE__ */ __name(($, strictSelector) => {
  if (!$)
    throwNoCheerioError("TimeResult");
  const location = $(import_google_sr_selectors.TimeSearchSelector.location).text().trim();
  const time = $(import_google_sr_selectors.TimeSearchSelector.time).text().trim();
  const timeInWords = $(import_google_sr_selectors.TimeSearchSelector.timeInWords).text().trim();
  if (isEmpty(strictSelector, location, time, timeInWords))
    return null;
  return {
    type: ResultTypes.TimeResult,
    location,
    time,
    timeInWords
  };
}, "TimeResult");
var CurrencyResult = /* @__PURE__ */ __name(($, strictSelector) => {
  if (!$)
    throwNoCheerioError("CurrencyResult");
  const from = $(import_google_sr_selectors.CurrencyConvertSelector.from).text().replace("=", "").trim();
  const to = $(import_google_sr_selectors.CurrencyConvertSelector.to).text().trim();
  if (isEmpty(strictSelector, from, to))
    return null;
  return {
    type: ResultTypes.CurrencyResult,
    from,
    to
  };
}, "CurrencyResult");

// src/search.ts
async function search(options) {
  if (!options)
    throw new TypeError(
      `Search options must be provided. Received ${typeof options}`
    );
  const requestConfig = prepareRequestConfig(options);
  const { data } = await (0, import_axios.default)(requestConfig);
  const cheerioApi = (0, import_cheerio.load)(data);
  const selectors = options.resultTypes || [OrganicResult];
  let searchResults = [];
  for (const selector of selectors) {
    const result = selector(
      cheerioApi,
      Boolean(options.strictSelector)
    );
    if (result)
      searchResults = searchResults.concat(result);
  }
  return searchResults;
}
__name(search, "search");
async function searchWithPages(options) {
  if (!options)
    throw new TypeError(
      `Search options must be provided. Received ${typeof options}`
    );
  if (typeof options.pages !== "number" && !Array.isArray(options.pages))
    throw new TypeError(
      `Page must be a number or an array of numbers. Received ${typeof options.pages}`
    );
  const searchResults = [];
  const pages = Array.isArray(options.pages) ? options.pages : Array.from({ length: options.pages }, (_, i) => i * 10);
  const baseRequestConfig = prepareRequestConfig(options);
  const selectors = options.resultTypes || [OrganicResult];
  for (const page of pages) {
    baseRequestConfig.params.set("start", String(page));
    const { data } = await (0, import_axios.default)(baseRequestConfig);
    const cheerioApi = (0, import_cheerio.load)(data);
    let pageResults = [];
    for (const selector of selectors) {
      const result = selector(
        cheerioApi,
        Boolean(options.strictSelector)
      );
      if (result)
        pageResults = pageResults.concat(result);
    }
    searchResults.push(pageResults);
  }
  return searchResults;
}
__name(searchWithPages, "searchWithPages");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  CurrencyResult,
  DictionaryResult,
  OrganicResult,
  ResultTypes,
  TimeResult,
  TranslateResult,
  search,
  searchWithPages
});
